@@ -1,8 +1,8 @@
 #!/bin/bash
 
-CLDR_VERSION=40
-UCD_VERSION=14.0.0
-EMOJI_VERSION=14.0
+CLDR_VERSION=42
+UCD_VERSION=15.0.0
+EMOJI_VERSION=15.0
 
 wget -c "https://www.unicode.org/Public/$UCD_VERSION/ucd/Blocks.txt"
 wget -c "https://www.unicode.org/Public/$UCD_VERSION/ucd/Jamo.txt"
@@ -18,5 +18,14 @@ unzip -jo core.zip common/supplemental/supplementalData.xml
 ./gen-confusables.py confusables.txt > confusables.h
 ./gen-emoji.py emoji-test.txt > emoji.h
 ./gen-hangul.py Jamo.txt > hangul.h
-./gen-names.py UnicodeData.txt > names.h
+./gen-names.py UnicodeData.txt emoji-test.txt > names.h
 ./gen-scripts.py supplementalData.xml PropertyValueAliases.txt > scripts.h
+
+rm Blocks.txt
+rm Jamo.txt
+rm PropertyValueAliases.txt
+rm UnicodeData.txt
+rm core.zip
+rm supplementalData.xml
+rm emoji-test.txt
+rm confusables.txt
